@@ -5,28 +5,18 @@ import datetime
 import json
 import logging
 
-from decimal import Decimal
 from supervisor.core.auth import APIKeyAuthWithExpires
 from supervisor.core.ws_thread import BitMEXWebsocket
 from supervisor.core import settings
 from supervisor.core.utils import errors
-from supervisor.core.utils.log import setup_custom_logger
-
-
-class DecimalEncoder(json.JSONEncoder):
-    """Add decimal encoding support for price operations."""
-    def default(self, obj):
-        if isinstance(obj, Decimal):
-            return float(obj)
-        return json.JSONEncoder.default(self, obj)
+from supervisor.core.utils.log import setup_api_logger
 
 
 # https://www.bitmex.com/api/explorer/
 class BitMEX(object):
 
     def __init__(self, test=True, symbol=None, api_key=None, api_secret=None, init_ws=True):
-        self.logger = logging.getLogger('root')
-        setup_custom_logger('root', logging.INFO)
+        self.logger = setup_api_logger('core', logging.INFO)
         self.base_url = settings.BASE_URL if not test else settings.BASE_TEST_URL
         self.symbol = symbol
         self.api_key = api_key
@@ -1141,7 +1131,7 @@ class BitMEX(object):
         # Make the request
         response = None
         try:
-            data = json.dumps(postdict, cls=DecimalEncoder)
+            data = json.dumps(postdict)
             if data == 'null':
                 data = ''
             self.logger.info("sending req to %s: %s" % (url, data or query or ''))
